ClassificationConfig

Struct ClassificationConfig 

pub struct ClassificationConfig {
    pub enforce: bool,
    pub dynamic_groups: bool,
    pub dynamic_groups_type: DynamicGroupType,
    pub levels: Vec<ClassificationLevel>,
    pub required: Vec<ClassificationMarking>,
    pub groups: Vec<ClassificationGroup>,
    pub subgroups: Vec<ClassificationSubGroup>,
    pub restricted: String,
    pub unrestricted: String,
}
A description of the configuration block used by assemblyline for classification schemes

Fields

enforce: bool

Turn on/off classification enforcement. When this flag is off, this completely disables the classification engine, any documents added while the classification engine is off gets the default unrestricted value

dynamic_groups: bool

Turn on/off dynamic group creation. This feature allow you to dynamically create classification groups based on features from the user.

dynamic_groups_type: DynamicGroupType

Set the type of dynamic groups to be used

levels: Vec<ClassificationLevel>

List of Classification level. Graded list were a smaller number is less restricted then an higher number.

required: Vec<ClassificationMarking>

List of required tokens: A user requesting access to an item must have all the required tokens the item has to gain access to it

groups: Vec<ClassificationGroup>

List of groups: A user requesting access to an item must be part of a least of one the group the item is part of to gain access

subgroups: Vec<ClassificationSubGroup>

List of subgroups: A user requesting access to an item must be part of a least of one the subgroup the item is part of to gain access

restricted: String

Default restricted classification

unrestricted: String

Default unrestricted classification. When no classification are provided or that the classification engine is disabled, this is the classification value each items will get