ClassificationGroup

Struct ClassificationGroup 

pub struct ClassificationGroup {
    pub aliases: Vec<NameString>,
    pub auto_select: bool,
    pub description: String,
    pub name: NameString,
    pub short_name: NameString,
    pub solitary_display_name: Option<NameString>,
    pub is_hidden: bool,
}
A group granted access to an object

Fields

aliases: Vec<NameString>

List of alternate names for this group

auto_select: bool

This is a special flag that when set to true, if any groups are selected in a classification. This group will automatically be selected too. (optional)

description: String

Long form description of marking

name: NameString

Long form canonical name of marking

short_name: NameString

Short form canonical name of marking

solitary_display_name: Option<NameString>

Assuming that this groups is the only group selected, this is the display name that will be used in the classification (that values has to be in the aliases of this group and only this group) (optional)

is_hidden: bool

Should the marking be skipped building UI options

Implementations

Source

impl ClassificationGroup

pub fn new(short_name: &str, name: &str) -> Self

Create access control group from canonical names

pub fn new_solitary( short_name: &str, name: &str, solitary_display: &str, ) -> Self

Create access control group from canonical names that has a special display form when presented alone