pub struct ClassificationMarking {
pub aliases: Vec<NameString>,
pub description: String,
pub name: NameString,
pub short_name: NameString,
pub require_lvl: Option<i32>,
pub is_required_group: bool,
pub is_hidden: bool,
}Expand description
A control or dissemination marking
Fields
aliases: Vec<NameString>List of alternate names for the current marking
description: StringLong form description of marking
name: NameStringLong form canonical name of marking
short_name: NameStringShort form canonical name of marking
require_lvl: Option<i32>The minimum classification level an item must have for this token to be valid. (optional)
is_required_group: boolThis is a token that is required but will display in the groups part of the classification string. (optional)
Should the marking be skipped building UI options
Implementations
Sourceimpl ClassificationMarking
impl ClassificationMarking
Sourcepub fn new(short_name: &str, name: &str, aliases: Vec<&str>) -> Self
pub fn new(short_name: &str, name: &str, aliases: Vec<&str>) -> Self
Create a marking from canonical names and aliases
Sourcepub fn new_required(short_name: &str, name: &str) -> Self
pub fn new_required(short_name: &str, name: &str) -> Self
Create a marking from canonical names that is a required group
Sourcepub fn unique_names(&self) -> Vec<NameString>
pub fn unique_names(&self) -> Vec<NameString>
Get all of the unique names used by this item