pub struct ClassificationSubGroup {
pub aliases: Vec<NameString>,
pub auto_select: bool,
pub description: String,
pub name: NameString,
pub short_name: NameString,
pub require_group: Option<NameString>,
pub limited_to_group: Option<NameString>,
pub is_hidden: bool,
}Expand description
A subgroup granted access to an object
Fields
aliases: Vec<NameString>List of alternate names for the current marking
auto_select: boolThis is a special flag that when set to true, if any groups are selected in a classification. This group will automatically be selected too. (optional)
description: StringLong form description of marking
name: NameStringLong form canonical name of marking
short_name: NameStringShort form canonical name of marking
require_group: Option<NameString>This is a special flag that auto-select the corresponding group when this subgroup is selected (optional)
limited_to_group: Option<NameString>This is a special flag that makes sure that none other then the corresponding group is selected when this subgroup is selected (optional)
Should the marking be skipped building UI options
Implementations
Sourceimpl ClassificationSubGroup
impl ClassificationSubGroup
Sourcepub fn new_aliased(short_name: &str, name: &str, aliases: Vec<&str>) -> Self
pub fn new_aliased(short_name: &str, name: &str, aliases: Vec<&str>) -> Self
Create a new subgroup with aliases
Sourcepub fn new_with_required(short_name: &str, name: &str, required: &str) -> Self
pub fn new_with_required(short_name: &str, name: &str, required: &str) -> Self
create a new subgroup with required group
Sourcepub fn new_with_limited(short_name: &str, name: &str, limited: &str) -> Self
pub fn new_with_limited(short_name: &str, name: &str, limited: &str) -> Self
Create a new subgroup limited in access to a given group