pub enum Errors {
InvalidClassification(String),
InvalidDefinition(String),
ClassificationNameEmpty,
}Expand description
An enumeration of all errors that can occur in the library
Variants
InvalidClassification(String)
An invalid classification string was provided
InvalidDefinition(String)
An invalid classification config was provided
ClassificationNameEmpty
A name given in a classification definition is an empty string