pub struct ClassificationGroup {
pub aliases: Vec<NameString>,
pub auto_select: bool,
pub description: String,
pub name: NameString,
pub short_name: NameString,
pub solitary_display_name: Option<NameString>,
pub is_hidden: bool,
}Expand description
A group granted access to an object
Fields
aliases: Vec<NameString>List of alternate names for this group
auto_select: boolThis is a special flag that when set to true, if any groups are selected in a classification. This group will automatically be selected too. (optional)
description: StringLong form description of marking
name: NameStringLong form canonical name of marking
short_name: NameStringShort form canonical name of marking
solitary_display_name: Option<NameString>Assuming that this groups is the only group selected, this is the display name that will be used in the classification (that values has to be in the aliases of this group and only this group) (optional)
Should the marking be skipped building UI options
Implementations